import colorama


def marker_on(s, marked, marker):
    if not marked:
        s += marker
        marked = True
    return s, marked


def marker_off(s, marked):
    if marked:
        s += colorama.Style.RESET_ALL
        marked = False
    return s, marked


def chardiff(a, b, marker=colorama.Style.BRIGHT):
    s = ""
    marked = False

    for i in range(len(a)):
        if i > len(b) - 1:
            s, marked = marker_on(s, marked, marker)
        else:
            if a[i] == b[i]:
                s, marked = marker_off(s, marked)
            else:
                s, marked = marker_on(s, marked, marker)
        s += a[i]
    s, marked = marker_off(s, marked)
    return s


def get_color(color):
    color = color.upper()
    if not hasattr(colorama.Fore, color):
        raise RuntimeError("Chosen color does not exist in pallet.")
    return getattr(colorama.Fore, color)



import argparse

import colorama

from . import chardiff, get_color


def get_args():
    parser = argparse.ArgumentParser(
        description="Compare two strings and find the diff"
    )
    parser.add_argument(
        "a", help="First string. This is the one printed to compare to."
    )
    parser.add_argument("b", help="Second string to compare to.")
    parser.add_argument("-c", "--color", help="Color to display diff", type=get_color)
    return parser.parse_args()


if __name__ == "__main__":
    args = get_args()
    colorama.init()
    if args.color:
        print(chardiff(args.a, args.b, marker=args.color))
    else:
        print(chardiff(args.a, args.b))



#!/usr/bin/env python

from distutils.core import setup

setup(
    name='chardiff',
    version='0.1a',
    description='Compare 2 strings and highlight differences',
    long_description=open("README.md").read(),
    author='Matt Copperwaite',
    author_email='matt@copperwaite.net',
    url='https://github.com/yamatt/python3-chardiff',
    packages=['chardiff'],
    scripts=['scripts/chardiff']
)
